@@ -15,14 +15,49 @@
 #
 
 import json
+import logging
+from functools import wraps
+from time import sleep
+
 import requests
 from requests.auth import HTTPBasicAuth
 from requests.exceptions import HTTPError
 
-import logging
 requests_log = logging.getLogger("requests")
 requests_log.setLevel(logging.WARNING)
 
+
+def retry_with_backoff(function_to_decorate=None):
+    def _decorate(func):
+        t = 1.0
+        sleep_times = []
+        while sum(sleep_times) <= 30:
+            sleep_times.append(t)
+            t = 2*t
+        sleep_times[-1] = StopIteration
+
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            for sleep_time in sleep_times:
+                try:
+                    return func(*args, **kwargs)
+                except Exception as e:
+                    if sleep_time == StopIteration:
+                        # raise the exception
+                        requests_log.warn('Failed to run %s after several retries' % func.__name__)
+                        raise e
+                    else:
+                        requests_log.warn('Unable to run %s. Sleeping [%s] seconds and retrying' % (func.__name__, sleep_time), exc_info=True)
+                        sleep(sleep_time)
+
+        return wrapper
+
+    if function_to_decorate:
+        return _decorate(function_to_decorate)
+
+    return _decorate
+
+
 class API(object):
     """
     Represents a connection to the Mortar API.
@@ -67,6 +102,7 @@ class API(object):
         """
         return '%s://%s/v2/%s' % (self.scheme, self.host, path)
 
+    @retry_with_backoff
     def post(self, path, payload):
         """
         Post to the API.
@@ -91,6 +127,7 @@ class API(object):
         self.raise_for_status(response)
         return response.json()
 
+    @retry_with_backoff
     def get(self, path, params=None):
         """
         Get from the API.
@@ -114,6 +151,7 @@ class API(object):
         self.raise_for_status(response)
         return response.json()
 
+    @retry_with_backoff
     def put(self, path, payload):
         """
         Put to the API.
@@ -138,6 +176,7 @@ class API(object):
         self.raise_for_status(response)
         return response.json()
 
+    @retry_with_backoff
     def delete(self, path):
         """
         Delete from the API.
