@@ -72,7 +72,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
                          git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                          pig_version=None, use_spot_instances=True, pipeline_job_id=None, job_type=JOB_TYPE_PIG,
                          cluster_tags=[], instance_type=None, project_build=None, cluster_configuration=None,
-                         job_description=None, emr_release_label=None, use_vpc_for_emr=None):
+                         job_description=None, emr_release_label=None):
     """
     Post a new job to a new cluster.
 
@@ -130,9 +130,6 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     :type emr_release_label: string
     :param emr_release_label: EMR release label of job (ex. "emr-5.8.0", see http://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-release-components.html)
 
-    :type use_vpc_for_emr: bool
-    :param use_vpc_for_emr: whether to instantiate cluster in VPC or classic
-
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -158,9 +155,6 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
     if emr_release_label:
         body["emr_release_label"] = emr_release_label
 
-    if use_vpc_for_emr:
-        body["use_vpc_for_emr"] = use_vpc_for_emr
-
     if pig_version:
         body["pig_version"] = pig_version
 
@@ -169,8 +163,7 @@ def post_job_new_cluster(api, project_name, script_name, cluster_size, cluster_t
 
 def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                              parameters=None, notify_on_job_finish=True, pig_version=None, use_spot_instances=True,
-                             job_type=JOB_TYPE_PIG, cluster_configuration=None, job_description=None, emr_release_label=None,
-                             use_vpc_for_emr=None):
+                             job_type=JOB_TYPE_PIG, cluster_configuration=None, job_description=None, emr_release_label=None):
     """
     Post a new job to a new cluster.
 
@@ -207,9 +200,6 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
     :type emr_release_label: string
     :param emr_release_label: EMR release label of job (ex. "emr-5.8.0", see http://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-release-components.html)
 
-    :type use_vpc_for_emr: bool
-    :param use_vpc_for_emr: whether to instantiate cluster in VPC or classic
-
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -230,9 +220,6 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
     if emr_release_label:
         body["emr_release_label"] = emr_release_label
 
-    if use_vpc_for_emr:
-        body["use_vpc_for_emr"] = use_vpc_for_emr
-
     if pig_version:
         body["pig_version"] = pig_version
 
@@ -243,7 +230,7 @@ def post_web_job_new_cluster(api, script_name, cluster_size, cluster_type=cluste
 def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluster_type=clusters.CLUSTER_TYPE_PERSISTENT,
                               git_ref='master', parameters=None, notify_on_job_finish=True, is_control_script=False,
                               pig_version=None, pipeline_job_id=None, job_type=JOB_TYPE_PIG, project_build=None,
-                              job_description=None, emr_release_label=None, use_vpc_for_emr=None):
+                              job_description=None, emr_release_label=None):
     """
     Post a new job to an existing cluster.
 
@@ -286,9 +273,6 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
     :type emr_release_label: string
     :param emr_release_label: EMR release label of job (ex. "emr-5.8.0", see http://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-release-components.html)
 
-    :type use_vpc_for_emr: bool
-    :param use_vpc_for_emr: whether to instantiate cluster in VPC or classic
-
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -309,9 +293,6 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
     if emr_release_label:
         body["emr_release_label"] = emr_release_label
 
-    if use_vpc_for_emr:
-        body["use_vpc_for_emr"] = use_vpc_for_emr
-
     if pig_version:
         body["pig_version"] = pig_version
 
@@ -319,7 +300,7 @@ def post_job_existing_cluster(api, project_name, script_name, cluster_id, cluste
 
 def post_web_job_existing_cluster(api, script_name, cluster_id, parameters=None,
                                   notify_on_job_finish=True, pig_version=None, job_type=JOB_TYPE_PIG,
-                                  job_description=None, emr_release_label=None, use_vpc_for_emr=None):
+                                  job_description=None, emr_release_label=None):
     """
     Post a new job to an existing cluster.
 
@@ -347,9 +328,6 @@ def post_web_job_existing_cluster(api, script_name, cluster_id, parameters=None,
     :type emr_release_label: string
     :param emr_release_label: EMR release label of job (ex. "emr-5.8.0", see http://docs.aws.amazon.com/emr/latest/ReleaseGuide/emr-release-components.html)
 
-    :type use_vpc_for_emr: bool
-    :param use_vpc_for_emr: whether to instantiate cluster in VPC or classic
-
     :raises: requests.exception.HTTPError: if a 40x or 50x error occurs
 
     :rtype: str:
@@ -367,9 +345,6 @@ def post_web_job_existing_cluster(api, script_name, cluster_id, parameters=None,
     if emr_release_label:
         body["emr_release_label"] = emr_release_label
 
-    if use_vpc_for_emr:
-        body["use_vpc_for_emr"] = use_vpc_for_emr
-
     return api.post('jobs', body)['job_id']
 
 
